@@ -23,7 +23,7 @@ class MailAccountUsage(APIObjectInterface):
         self.mail_account_id = obj["mail_account_id"]
         self.timestamp = obj["timestamp"]
 
-        self.datetime_object = datetime.strptime(self.timestamp, "%Y-%m-%dT%H:%M:%S.%f")
+        self.datetime_object = datetime.strptime(self.timestamp, "%Y-%m-%dT%H:%M:%S")
 
         self.mail_account = self.support.get_mail_accounts(id_=self.mail_account_id)[0]
 
